@@ -3,6 +3,6 @@ require File.dirname(__FILE__) + '/../lib/terminal-table'
 
 class String
   def deindent
-    gsub /^ */, ''
+    strip.gsub(/^ */, '')
   end
 end
